/** 
	Android通知页面调用getBody方法，获得详细页JSON。
	因为Android直接传值，遇到特殊字符会有乱码。所以需要页面主动调用返回值。
	IOS没有这个问题。
	JSON结构：
	{
		"id" : 内容ID，
		"title" : 内容标题，
		"source" : 来源，
		"publishTime" : 发布时间，
		"text" : 内容正文，
		"topCount" : 顶的次数，
		"ad" : 关联占位广告信息
		{
			"adId" : 广告ID
			"title" : 广告标题
			"imgUrl" : 广告图片访问地址
			"link" : 广告链接
			"adText" : 广告正文
		},
		"vote" : 关联的投票信息
		{
			"voteId" : 投票ID
			"title" : 投票调查标题
			"subtopicId" : 主题ID
			"subtopicTitle" :主题标题
			"multiselect" : 是否支持多选true，false；
			"itemList" : 投票选项列表
			[
				{
					"itemId" : 选项ID
					"title" : 选项标题
					"count" : 已选票数
					"isDefault" : 是否默认选中。1、是；0、否；
				}
			]
		},
		"commentList" : 该内容顶的次数最多的前两条评论
		[
			{
				"id" : 评论的ID
				"memberName" : 评论的会员昵称
				"memberId" : 评论的会员ID
				"memberImg" : 评论的会员头像访问路径
				"createTime" : 评论的创建时间
				"comment" : 评论的具体内容
				"topCount" : 顶的次数
			}
		],
		"relatedList" : 相关内容列表（两条）
		[
			{
				"contentType" : 内容类型：（1、活动；2、抽奖；3、投票调查；4、直播间；5、图文资讯；6、图集；7、专题；8、占位广告；9、视频） 
				"id" : 内容ID
				"title" : 内容标题
				"imgurl" : 图片访问路径
				"publishTime" : 发布时间
				"summary" : 摘要
			}
		]
	}
**/
function setBody( jsonString )
{
	var detail;
	if( null == jsonString &&　window.java && window.java.getBody )
	{
		jsonString = window.java.getBody();
		detail = JSON.parse( jsonString );
	}
	else
		detail = jsonString;
	//	detail = JSON.parse( jsonString );
	//alert( "" + jsonString );
	if( null == jsonString ) return;
	
	/** 标题 **/
    $( "#title" ).html( detail.title );
	/** 来源 **/
    $( "#source" ).html( detail.source );
	/** 发布时间 **/
    $( "#time" ).html( detail.publishTime );
	/** 责编 **/
    $( "#editor" ).html( detail.editor );
	/** 责编 **/
    $( "#editor" ).html( detail.editor );
	/** 正文 **/
	$( "#info" ).html( detail.text );
	/** 处理正文中的图片点击放大 **/
	addImgListener();
	/** 处理正文中的内链点击 **/
	addContentLinkListener();
	/** 处理正文中的视频 **/
	replaceVideo();
	/** 设置顶数量 **/
	$( "#top" ).html( detail.topCount );
	$( "#top_image" ).html( detail.topCount );
	/** 相关内容 **/
	setRelatedContent( detail.relatedList );
	/** 设置评论 **/
	setCommentList( detail.commentList );
	/** 设置广告 **/
	setAd( detail.ad );
	/** 设置投票 **/
	setVote( detail.vote );
	
	$( ".sjshare" ).css( "display", "" );
	$( ".commentbox" ).css( "display", "" );
	
	/** 强制处理图片、表格 **/
	$( "#info img, #info table" ).each(
	function( i, elem )
	{
		if( elem.getAttribute( "data-plugin-type" ) == "video" ) return true;
		elem.style.width = "100%";
		elem.style.height = "auto";
		elem.style.margin = "0";
	} );
}


/** 单独设置顶数量 **/
function setTop( topCount ) {
	$( "#top" ).html( topCount );
	$( "#top_image" ).html( topCount );
	
	/** 显示+1动画 **/
	var span = "<span class='zan_info'>+1</span>";
	$( ".ding" ).append( span );
	setTimeout( function(){ $(".zan_info").css( "top", -30 ); }, 100 );
	setTimeout( function(){ $(".zan_info").css( "opacity", 0.2 ); }, 100 );
	setTimeout( function(){ $(".zan_info").remove(); }, 600 );
}


/** 评论点赞数量 **/
function setCommentTop( commentId, topCount ) {
	$( "#comment_" + commentId ).html( topCount );
	$( "#comment_" + commentId ).parent( ".comt_ding" ).attr( "data-top-count", topCount );
}

/** 设置广告 **/
function setAd( ad ) 
{
alert(123);
	if( ad.title == null ) return;
	$( ".popularize" ).css( "display", "" );
   // $( "#adtitle" ).html( "<span class='poptg_gg'>推广</span>" + ad.title + "<span class='poptg_jt'>&gt;</span>" );
    $( "#adtitle" ).html( "<span class='poptg_gg'>推广</span>" + ad.title );
    //$( "#adimgurl" ).html( "<a href="+ad.link+"><img src=" + ad.imgUrl + "></a>" );
	  $( "#adimgurl" ).html( "<img src=" + ad.imgUrl + ">" );
    $( "#adtitle" ).attr( "data-ad-id", ad.adId );
    $( "#adimgurl" ).attr( "data-ad-id", ad.adId );
	
	$( "#adtitle" ).bind( "click", function( event ) { onClickAd( $( "#adtitle" ).attr( "data-ad-id" ) ); } );
	$( "#adimgurl" ).bind( "click", function( event ) { onClickAd( $( "#adimgurl" ).attr( "data-ad-id" ) ); } );
}

/** 设置投票 **/
function setVote( vote ) 
{
	if( vote.voteId == null ) return;
	$( "#votelist" ).css( "display", "" );
	var html = "";
	$( "#votelist" ).html( html );
	html += "<div class='sj_radio'>";
	html +=		"<div class='pop_tgcom'>";
	html +=			"<h5 class='sjradio_bt'>" + vote.title + "</h5>";
	var inputType = ( vote.multiselect == 1 ) ? "checkbox" : "radio";
	for( var i = 0; i < vote.itemList.length; i++ )
	{
		var data = vote.itemList[i];
		html += "<div class='hdi_fxk'>";
		html +=		"<label>";
		html +=			"<input name='vote" + vote.voteId + "'";
		html +=				( data.isDefault == 1 ) ? "" : " checked";
		html +=				" type='" + inputType + "'";
		html +=				" value=" + data.itemId + ">";
		if( vote.supportPicture == 0 )
			html +=		data.title;
		else
			html += 	"<img src='" + data.resourceUrl + "'/>";
		html +=		"</label>";
		html +=	"</div>";
	}
	html +=			"<div class='hdvc_btn'>";
	html +=				"<button class='hdbtm_input' data-vote-id=" + vote.voteId + ">提交</button>";
	html +=			"</div>";
	html +=		"</div>";
	html +=	"</div>";
	$( "#votelist" ).html( html );
	
	$( "#votelist .hdbtm_input" ).unbind( "click" );
	$( "#votelist .hdbtm_input" ).bind( "click", 
	function( event ) 
	{
		var itemIds = [];
		$( "#votelist input[type='" + inputType + "']:checked" ).each(
		function( i, ele ) {
        	itemIds.push( ele.value );
        } );
		//alert(  event.target.getAttribute( "data-vote-id" ) + ", " + itemIds.toString() );
		onClickVoteSubmit( this.getAttribute( "data-vote-id" ), itemIds.toString() );
	} );
}


/** 相关内容 **/
function setRelatedContent( relatedList ) 
{
	var html = "";
	$( "#tjnews" ).html( html );
	for( var r = 0; r < relatedList.length; r++ )
	{
		var data = relatedList[r];
		html += "<li data-id=" + data.id + " data-content-id=" + data.contentId + ">";
		html +=		"<table cellpadding=0 cellspacing=0 class='userbox'>";
		html +=			"<tr>";
		html +=				"<td>";
		html +=			"<img src=" + data.imgUrl + " />";
		html +=				"</td>";
		html +=				"<td>";
		html +=		"<div class='newstitle'>";
		html +=			"<div class=news_bt>" + data.title + "</div>";
		html +=			"<div class=news_js>" + data.summary + "</div>";
		html +=			"<div class=news_date>" + data.publishTime + "</div>";
		html +=		"</div>";
		html +=				"</td>";
		html +=			"</tr>";
		html +=		"</table>";
		html +=		"<div class='clear'></div>";
		html +=	"</li>";
	}
	$( "#tjnews" ).html( html );
	$( "#tjnews li" ).unbind( "click" );
	$( "#tjnews li" ).bind( "click", 
	function( event )
	{ onClickRelatedContent( this.getAttribute( "data-content-id" ) ); } );
	$( ".newsbox" ).css( "display", html == "" ? "none" : "" );
}

/** 设置评论 **/
function setCommentList( commentList ) 
{
	var html = "";
	$( "#commentlist" ).html( html );
	for( var c = 0; c < commentList.length; c++ )
	{
		var data = commentList[c];
		var memberImg =   data.memberImg.length > 0  ? data.memberImg : "images/user_default.png";
		var memberName = data.memberName.length > 0  ? data.memberName : '' ;
		html += "<li data-id=" + data.id + ">";
		html +=		"<table cellpadding=0 cellspacing=0 class='userbox'>";
		html +=			"<tr>";
		html +=				"<td>";
		html +=					"<img src='"+ data.memberImg +"'/>";
		html +=				"</td>";
		html +=				"<td>";
		html +=					"<div class='commentinfo'>";
		html +=						"<div class='comt_tb'>";
		html +=							"<div class='cont_left'>";
		html +=								"<p class='contl_wz'>"+ memberName +"</p>";
		html +=								"<p class='contl_date'>"+ data.createTime +"</p>";
		html +=							"</div>";
		html +=							"<div class='comt_ding' data-id=" + data.id + " data-top-count=" + data.topCount + ">";
		html +=								"<img src='images/comt_ding.png'/>";
		html +=								"<span id='comment_" + data.id + "'>" + data.topCount + "</span>";
		html +=							"</div>";
		html +=						"</div>";
		html +=						"<div class='plcomt_nr'>" + data.comment + "</div>";
		html +=					"</div>";
		html +=				"</td>";
		html +=			"</tr>";
		html +=		"</table>";
		html +=		"<div class='clear'></div>";
		html +=	"</li>";
	}
	$( "#commentlist" ).html( html );
	$( "#commentlist .comt_ding" ).unbind( "click" );
	$( "#commentlist .comt_ding" ).bind( "click", 
	function( event )
	{ onClickTopComment( this.getAttribute( "data-id" ), this.getAttribute( "data-top-count" ) ); } );
}

/** 处理正文中的图片点击放大 **/
function addImgListener()
{
	$( "#info img" ).each(
	function( i, img ) 
	{
		if( img.getAttribute( "data-plugin-type" == "video" ) ) return true;
     	img.setAttribute( "data-index", i );
		img.onclick = onClickContentImage;
    } );
}

/** 处理正文中的内链点击 **/
function addContentLinkListener()
{
	$( "#info label[data-plugin-type='content']" ).each(
	function( i, lab ) 
	{
		lab.onclick = onClickContentLink;
    } );
}



////////////////////////////////////////////////////////////////////////////////////////////////////





/** 设置投票结果 **/
function setVoteResult( jsonString )
{
	var result = ( typeof( jsonString ) == "string" ) ? JSON.parse( jsonString ) : jsonString;
	var vote = result.vote;
	
	var total = 0;
	for( var i = 0; i < vote.itemList.length; i++ )
		total += Number( vote.itemList[i].count );
	
	var html = "";
	$( "#votelist" ).html( html );
	html += "<div class='sj_radio'>";
	html +=		"<div class='pop_tgcom'>";
	html +=			"<h5 class='sjradio_bt'>" + vote.title + "</h5>";
		
	for( var i = 0; i < vote.itemList.length; i++ )
	{
		var data = vote.itemList[i];
		var per = Math.floor( data.count * 10000 / total ) / 100;
		html += "<div class='hdi_fxk'>";
		if( vote.supportPicture == 0 )
			html +=		"<label>" + data.title + "</label>";
		else
			html += 	"<label><img class='img' src='" + data.resourceUrl + "'/></label>";
		html +=		"<table cellspacing='0' cellpadding='0'>";
		html +=			"<tr>";
		html +=				"<td>";
		html +=					"<div class='val_back'>";
		html +=						"<div class='val val_color" + ( i % 4 ) + "' style='width:" + per + "%;'></div>";
		html +=						"</div>";
		html +=				"</td>";
		html +=				"<td>";
		html +=					data.count + "&nbsp;(&nbsp;" +per + "%&nbsp;)";
		html +=				"</td>";
		html +=			"</tr>";
		html +=		"</table>";
		html +=	"</div>";
	}
	
	html +=		"</div>";
	html +=	"</div>";
	$( "#votelist" ).html( html );
} 





////////////////////////////////////////////////////////////////////////////////////////////////////


/** 点击视频 **/
function onClickVideo( url ) {
	if ( window.java ) {
		window.java.onClickVideo( url );
	}
	else window.location = "(" + url + "(playVideo";
}

/** 文章点赞 **/
function onClickTop() {
	if ( window.java ) {
		window.java.onClickTop();
	}
	else window.location = "top";
}

/** 分享到微信盆友圈 **/
function onClickShareToWeiXin() {
	if ( window.java ) {
		window.java.onClickShareToWeiXin();
	}
	else window.location = "wxpy";
}

/** 分享到微信好友 **/
function onClickShareToMoments() {
	if ( window.java ) {
		window.java.onClickShareToMoments();
	}
	else window.location = "wx";
}

/** 更多分享 **/
function onClickShareToMore() {
	if ( window.java ) {
		window.java.onClickShareToMore();
	}
	else window.location = "onClickShareToMore";
}

/** 广告点击 **/
function onClickAd( adId ) {
alert("广告");
	if ( window.java ) {
		window.java.onClickAd();
	}

	else window.location = "(" + adId + "(onClickAd";
}

/** 查看评论列表 **/
function onClickMoreComment() {
	if ( window.java ) {
		window.java.onClickMoreComment();
	}
	else window.location = "moreComments";
}

/** 点击相关内容 **/
function onClickRelatedContent( id ) {
	if ( window.java ) {// alert(id);
		window.java.onClickRelatedContent( id );
	}
	else window.location = "(" + id + "(gotonetNews";
}

/** 评论点赞 **/
function onClickTopComment( id, topCount ) {
	if ( window.java ) {
		window.java.onClickTopComment( id );
	}
	else window.location = "(" + id + "(" + topCount + "(onClickTopComment";
}

/** 提交投票 **/
function onClickVoteSubmit( voteId, itemIds ) {
	if ( window.java ) {
		window.java.submitVote( voteId, itemIds );
	}
	else window.location = "(" + voteId + "(" + itemIds+"(submitVote";
}



/** 点击通知app显示大图 **/
function onClickContentImage()
{
	var index = this.getAttribute( "data-index" );
	var list = new Array();
	$( "#info img[data-plugin-type='image']" ).each(
	function( i, img ) 
	{
        list.push( "\"" + img.src + "\"" );
    } );
	
	if ( window.java ) {
		window.java.onClickImage( "[" + list.toString() + "]", index );
	}
	else window.location = "(" + "[" + list.toString() + "]" + "(" + index +"(onClickImage";
}



/** 点击通知app打开内链 **/
function onClickContentLink()
{
	var id = this.getAttribute( "data-id" );
	var originalId = this.getAttribute( "data-original-id" );
	var contentType = this.getAttribute( "data-content-type" );
	
	if ( window.java ) {
		window.java.onClickContentLink( id, originalId, contentType );
	}
	else window.location = "(" + id + "(" + originalId + "(" + contentType + "(onClickContentLink(";
}



//////////////////////////////////////////////////////////////////////////////////////////////////




/** 处理正文视频 **/
function replaceVideo()
{
	$( "#info section[data-plugin-type='video']" ).each(
		function( i, section ) 
		{
            /**
			<section data-plugin-type='video' style='text-align:center;margin-bottom:1em;'>
			 	<img src='节目图片' data-value='节目JSON'
					 style='max-width:100%;height:auto;margin:10px auto;'></img>
			</section>
			**/
			/**
			 {
				id: [ Integer ] 节目ID,
				createdTime: [ String ] 创建时间，yyyy-MM-dd hh:mm:ss,
				programName: [ String ] 节目名称,
				image: [ String ] 节目缩略图,
				video: [ Object ] 节目下视频
				{
					videoId: [ Integer ] 视频ID,
					displayName: [ String ] 视频名称,
					videoImage: [ String ] 视频图片,
					streamList: [ Array ] 码流列表
					[
						{
							streamId: [ Integer ] 码流名称ID,
							streamDisplayName: [ String ] 码流显示名称
							url: [ String ] 完整播放地址,
							isDefault: [ Integer ] 默认播放1、是；0、否
						}
					]
				}
			 }
			**/
			var h = $( section ).find( "img" ).get(0).offsetHeight;
			$( section ).append( "<div class='video_player_black'></div>" );
			$( section ).append( "<div class='video_play_btn'></div>" );
			section.className = "video_player_section";
			
			$( section ).find( ".video_play_btn" ).unbind( "click" );
			$( section ).find( ".video_play_btn" ).bind( "click", 
			function( event ) 
			{
				var program = JSON.parse( $( event.target ).parent( "section" ).find( "img" ).get(0).getAttribute( "data-value" ) );
				if( null == program ) return;
				var video = program.video;
				if( null == video ) return;
				if( null == video.streamList ) return;
				if( 0 == video.streamList.length ) return;
				var stream = video.streamList[0];
				for( var s = 0; s < video.streamList.length; s++ )
					if( video.streamList[s].isDefault == 1 )
						stream = video.streamList[s];
				
				onClickVideo( stream.url );
			} );
			
        } );
}