/** 初始化Vue **/
var vm;
$().ready( function() {
    /** 初始化数据 **/
    vm = new Vue( {
        el: ".base",
        data: { title: "", content: "", editor: "", },
        methods: {
            init: function() {
                /** 处理正文中段首空格占位 **/
                replaceNBSP();
                /** 处理正文中的图片点击放大 **/
                addImgListener();
                /** 处理正文中的内链点击 **/
                addContentLinkListener();
                /** 处理正文中的视频 **/
                replaceVideo();
                /** 处理正文音频 **/
                replaceAudio();
                /** 强制处理图片、表格、内链 **/
                formatContent();
            }
        },
        updated: function() {
            /** 显示页面 **/
            $( ".base" ).removeClass( "off" );
            /** 初始化 **/
            var me = this;
            me.init();
        }
    } );
} );

/**
 Android通知页面调用getBody方法，获得详细页JSON。
 因为Android直接传值，遇到特殊字符会有乱码。所以需要页面主动调用返回值。
 IOS没有这个问题。
 **/
function setBody( jsonString ) {
    var detail;
    if( ( null == jsonString || "" == jsonString ) && window.java && typeof window.java.getBody == "function" ) {
        jsonString = window.java.getBody();
        detail = JSON.parse( jsonString );
    }
    else detail = jsonString;
    /** 修改vm的数据 **/
    vm.$data.title = detail.title;
    vm.$data.content = detail.text;
    vm.$data.editor = detail.editor;
    /** 返回顶部 **/
    $( "body" ).get(0).scrollTop = 0;
    $( "html" ).get(0).scrollTop = 0;
}



/** 处理正文中的段首占位空格 **/
function replaceNBSP() {
    if(  $( ".content" ).length == 0 ) return;
    var nodes = $( ".content" ).get(0).childNodes;
    if( nodes ){
        for (var i = 0; i < nodes.length; i++) {
            var nodeStr = $(nodes[i]).html();
            if (nodeStr) {
                var str = "";
                for (var s = 0; s < nodeStr.length; s++) {
                    if (nodeStr[s] == " ")
                        str += "&nbsp;";
                    else {
                        if (s > 0) nodeStr = nodeStr.replace(nodeStr.substr(0, s), str);
                        break;
                    }
                }
                $(nodes[i]).html(nodeStr);
            }
        }
    }
}




/** 处理正文中的内链点击 **/
function addContentLinkListener() {
    $( ".content label[data-plugin-type='content']" ).each( function( i, lab ) {
        lab.onclick = onClickContentLink;
    } );
}




/** 处理正文中的图片点击放大 **/
function addImgListener() {
    $( ".content img" ).each( function( i, img ) {
        if( img.getAttribute( "data-plugin-type" == "video" ) ) return true;
        img.setAttribute( "data-index", i );
        img.onclick = onClickContentImage;
    } );
}




/** 处理正文视频 **/
function replaceVideo() {
    /**
     <section data-plugin-type='video' style='text-align:center;margin-bottom:1em;'>
     <img src='节目图片' data-value='节目JSON' style='max-width:100%;height:auto;margin:10px auto;'></img>
     </section>
     **/
    /**
     {
        id: [ Integer ] 节目ID,
        createdTime: [ String ] 创建时间，yyyy-MM-dd hh:mm:ss,
        programName: [ String ] 节目名称,
        image: [ String ] 节目缩略图,
        video: [ Object ] 节目下视频
        {
            videoId: [ Integer ] 视频ID,
            displayName: [ String ] 视频名称,
            videoImage: [ String ] 视频图片,
            streamList: [ Array ] 码流列表
            [
                {
                    streamId: [ Integer ] 码流名称ID,
                    streamDisplayName: [ String ] 码流显示名称
                    url: [ String ] 完整播放地址,
                    isDefault: [ Integer ] 默认播放1、是；0、否
                }
            ]
        }
     }
     **/
    $( "section[data-plugin-type='video']" ).each( function( i, section ) {
        $( section ).find( "div" ).replaceWith( "<div class='video_play_btn'></div>" );
        $( section ).find( ".video_play_btn" ).unbind( "click" );
        $( section ).find( ".video_play_btn" ).bind( "click", function( event ) {
            var program = JSON.parse( $( event.target ).parent( "section" ).find( "img" ).get(0).getAttribute( "data-value" ) );
            if( null == program ) return;
            var video = program.video;
            if( null == video ) return;
            if( null == video.streamList ) return;
            if( 0 == video.streamList.length ) return;
            var stream = video.streamList[0];
            for( var s = 0; s < video.streamList.length; s++ )
                if( video.streamList[s].isDefault == 1 )
                    stream = video.streamList[s];

            onClickVideo( stream.url );
        } );

    } );
}




/** 处理正文音频 **/
function replaceAudio() {
    $( "embed[data-plugin-type='audio']" ).each( function( index, embed ) {
        var program = JSON.parse( decodeURIComponent( embed.getAttribute( "data-value" ) ) );
        console.dir( program );
        var url = program.mmsURL + "/amc/getProgramVideoPlayUrl.jspa?callback=?";
        $.getJSON( url, { programId:program.id, programVideoId:program.video.videoId, videoType:"PC" }, function( res ) {
            var stream = res.data.streamList[0];
            $( embed ).replaceWith( "<audio controls src='" + stream.url + "'></audio>" );
        } );
    } );
}




/** 点击播放视频 **/
function onClickVideo( url ) {
    if ( window.java )
        window.java.onClickVideo( url );
    else window.location = "(" + url + "(playVideo";
}




/** 点击显示大图 **/
function onClickContentImage( event ) {
    var index = this.getAttribute( "data-index" );
    var list = new Array();
    $( ".content" ).find( "img" ).each( function( i, img ) {
        list.push( img.src );
    } );
    var url = list[index];
    if( !url ) url = this.src;
    if ( window.java )
        window.java.onClickImage( "[" + list.toString() + "]", url, index );
    else window.location = "(" + list.toString() + "(" + url + "(" + index +"(onClickImage";
}



/** 点击通知app打开内链 **/
function onClickContentLink() {
    var id = this.getAttribute( "data-id" );
    var originalId = this.getAttribute( "data-original-id" );
    var contentType = this.getAttribute( "data-content-type" );

    if ( window.java ) {
        window.java.onClickContentLink( id, originalId, contentType );
    }
    else window.location = "(" + id + "(" + originalId + "(" + contentType + "(onClickContentLink";
}



/** 强制处理图片、表格、内链 **/
function formatContent() {
    $( ".content img, .content table" ).each( function( i, elem ) {
        if( elem.getAttribute( "data-plugin-type" ) == "video" ) return true;
        elem.style.width = "100%";
        elem.style.height = "auto";
        elem.style.margin = "0";
    } );
    $( "section[data-plugin-type]").css( "text-indent", "0" );
    $( "section[data-plugin-type]" ).find( "center" ).css( "text-indent", "0" );
}